pub enum AbrCostFunction {
SumCost,
MaxCost,
CountCost,
WeightedCost(HashMap<HypothesisId, f64>),
}Expand description
Strategy for computing the total cost of a hypothesis set.
Variants
SumCost
Sum of all individual costs.
MaxCost
Maximum individual cost.
CountCost
Cardinality (number of hypotheses chosen).
WeightedCost(HashMap<HypothesisId, f64>)
Weighted sum: each hypothesis id maps to an additional weight multiplier.
Implementations
Sourceimpl AbrCostFunction
impl AbrCostFunction
Sourcepub fn compute(
&self,
ids: &[HypothesisId],
hypotheses: &HashMap<HypothesisId, AbrHypothesis>,
) -> f64
pub fn compute( &self, ids: &[HypothesisId], hypotheses: &HashMap<HypothesisId, AbrHypothesis>, ) -> f64
Compute the total cost for a set of hypotheses.