pub struct TensorActivation { /* private fields */ }Expand description
Activation layer with forward/backward support and call statistics.
Implementations
Sourceimpl TensorActivation
impl TensorActivation
Sourcepub fn new(config: ActivationConfig) -> Self
pub fn new(config: ActivationConfig) -> Self
Create a new activation layer from the given configuration.
Sourcepub fn gelu(x: f64) -> f64
pub fn gelu(x: f64) -> f64
GELU activation (approximate): 0.5 * x * (1 + tanh(sqrt(2/pi) * (x + 0.044715 * x^3)))
Sourcepub fn softmax(input: &[f64]) -> Vec<f64>
pub fn softmax(input: &[f64]) -> Vec<f64>
Softmax over a slice of values, using the log-sum-exp trick for numerical stability.
Sourcepub fn forward(&mut self, input: &[f64]) -> Vec<f64>
pub fn forward(&mut self, input: &[f64]) -> Vec<f64>
Apply the configured activation element-wise (Softmax across all elements).
Sourcepub fn backward(&mut self, input: &[f64], grad_output: &[f64]) -> Vec<f64>
pub fn backward(&mut self, input: &[f64], grad_output: &[f64]) -> Vec<f64>
Compute the gradient of the loss w.r.t. the activation input.
input– the original pre-activation values.grad_output– the upstream gradient (dL/d(output)).
Returns dL/d(input).
Sourcepub fn stats(&self) -> ActivationStats
pub fn stats(&self) -> ActivationStats
Return runtime statistics.