pub enum CausalError {
NodeAlreadyExists(String),
NodeNotFound(String),
CycleDetected,
InvalidEdge(String),
}Expand description
Errors that can be produced by the CausalInferenceEngine.
Variants
NodeAlreadyExists(String)
A node with the same identifier already exists in the graph.
NodeNotFound(String)
A referenced node does not exist in the graph.
CycleDetected
Adding the requested edge would create a directed cycle.
InvalidEdge(String)
The edge specification is otherwise invalid.