pub struct CodecNegotiationRecord {
pub local_offered: Vec<CodecId>,
pub remote_offered: Vec<CodecId>,
pub agreed: Option<CodecId>,
pub negotiated_at: Instant,
pub negotiation_ms: u64,
}Expand description
Record of a single codec negotiation between the local peer and a remote peer.
Fields
local_offered: Vec<CodecId>Codec ids offered by the local side, in preference order.
remote_offered: Vec<CodecId>Codec ids offered by the remote side, in any order.
agreed: Option<CodecId>The codec that was agreed upon, or None if no common codec was found.
negotiated_at: InstantWall-clock time at which negotiation completed.
negotiation_ms: u64Duration of the negotiation in milliseconds.