pub enum ConsensusError {
RoundNotFound(u64),
RoundAlreadyExists(u64),
RoundNotActive(u64),
DuplicateVote {
peer_id: String,
round_id: u64,
},
}Expand description
Errors that can be returned by RoundConsensusTracker operations.
Variants
RoundNotFound(u64)
No round with the given ID exists.
RoundAlreadyExists(u64)
A round with this ID was already registered.
RoundNotActive(u64)
The operation requires the round to be Active but it is in a
terminal state.
DuplicateVote
This peer has already cast a vote in this round.