Module execution_tracer

Module execution_tracer 

TensorExecutionTracer — records detailed execution traces of TensorLogic inference operations for debugging, profiling, and replay purposes.

Structs

TensorExecutionTracer
Records detailed execution traces of TensorLogic inference operations.
TraceEvent
A single recorded event in the execution trace.
TraceSummary
Aggregated summary statistics for a single session.
TracerConfig
Configuration for TensorExecutionTracer.
TracerStats
Whole-tracer statistics (across all sessions).

Enums

TraceEventKind
Kinds of events that can be recorded in an execution trace.