pub struct TracerConfig {
pub max_events: usize,
pub enabled: bool,
}Expand description
Configuration for TensorExecutionTracer.
Fields
max_events: usizeMaximum number of events retained in the ring buffer. Oldest events are evicted when this limit is reached.
enabled: boolWhen false all record calls are no-ops.