pub struct ClippingResult {
pub tensor_id: u64,
pub original_norm: f64,
pub clipped_norm: f64,
pub was_clipped: bool,
}Expand description
The result of a clipping operation on a single tensor.
Fields
tensor_id: u64The id of the tensor that was (possibly) clipped.
original_norm: f64L2 norm of the tensor before clipping.
clipped_norm: f64L2 norm of the tensor after clipping.
was_clipped: booltrue if any values were actually changed by the clipper.