pub struct DeltaStats {
pub total_encoded: u64,
pub total_full_sends: u64,
pub total_delta_sends: u64,
}Expand description
Cumulative statistics for a DeltaEncoder.
Fields
total_encoded: u64Total number of encode calls.
total_full_sends: u64Number of times the full gradient was sent (no previous available).
total_delta_sends: u64Number of times a delta was sent instead of the full gradient.