pub struct SparsifierStats {
pub total_rounds: u64,
pub total_elements_kept: u64,
pub total_elements_dropped: u64,
pub total_residual_applied: u64,
}Expand description
Cumulative statistics for a GradientSparsifier.
Fields
total_rounds: u64Total number of sparsification rounds completed.
total_elements_kept: u64Total number of gradient elements that were kept (sent).
total_elements_dropped: u64Total number of gradient elements that were dropped (deferred to residual).
total_residual_applied: u64Total number of residual elements that were re-applied to the gradient.