pub struct GraphEdge {
pub from: u64,
pub to: u64,
pub data_bytes: u64,
}Expand description
A directed edge between two nodes in the tensor computation graph.
Fields
from: u64Source node identifier.
to: u64Destination node identifier.
data_bytes: u64Number of bytes transferred across this edge when it is cut.