pub struct SchedulerConfig {
pub max_concurrent: usize,
pub max_queue_size: usize,
}Expand description
Configuration for TensorInferenceScheduler.
Fields
max_concurrent: usizeMaximum number of jobs that may be Running simultaneously.
max_queue_size: usizeMaximum number of jobs that may be Pending at one time.