Module kb_federation

Module kb_federation 

Knowledge Base Federation

Provides functions for merging, exporting, and importing knowledge bases across the IPFRS network using content-addressed IPLD blocks.

Overview

Structs

KbMergeDiff
Summary of changes produced by merging two knowledge bases.

Enums

KbConflict
A conflict detected when merging two knowledge bases.

Functions

export_kb_as_cid
Export the current knowledge base of store as an IPLD block DAG.
import_remote_kb
Import a KB snapshot identified by remote_cid into store, merging with the existing local KB.
merge_knowledge_bases
Merge two knowledge bases, deduplicating facts and rules by content hash.