pub struct TaskAdaptation {
pub task_id: TaskId,
pub adapted_weights: Vec<f64>,
pub adapted_bias: f64,
pub support_loss: f64,
pub query_loss: f64,
pub steps: u32,
}Expand description
The result of adapting the meta-parameters to a specific task.
Fields
task_id: TaskIdWhich task these weights were adapted for.
adapted_weights: Vec<f64>Weights after inner-loop gradient descent.
adapted_bias: f64Bias after inner-loop gradient descent.
support_loss: f64Mean loss on the support set after the final inner-loop step.
query_loss: f64Mean loss on the query set evaluated with the adapted weights.
steps: u32Number of inner-loop gradient-descent steps taken.