pub struct FeatureSpec {
pub name: String,
pub transforms: Vec<FeatureTransform>,
}Expand description
An ordered list of transforms to apply to a single named input feature.
Fields
name: StringName of the feature to look up in the input map.
transforms: Vec<FeatureTransform>Sequential transforms to apply. Applied in order, left-to-right.