pub struct PrunerConfig {
pub strategy: PruningStrategy,
pub seed: u64,
pub update_mask: bool,
}Expand description
Configuration bundle passed to ModelPruner::new.
Fields
strategy: PruningStrategyWhich pruning algorithm to apply.
seed: u64Seed for the internal xorshift64 PRNG (used by
PruningStrategy::RandomPruning).
update_mask: boolWhen true the pruner maintains and updates a boolean mask on each
LayerWeights; when false the mask field is left as None.