pub struct HopTrace { /* private fields */ }Expand description
Complete trace of all hops taken during a multi-hop resolution attempt.
Implementations
Sourceimpl HopTrace
impl HopTrace
Sourcepub fn remote_hops(&self) -> Vec<&HopRecord>
pub fn remote_hops(&self) -> Vec<&HopRecord>
References to hops that involved a remote peer (peer_id is Some).
Sourcepub fn resolved_count(&self) -> usize
pub fn resolved_count(&self) -> usize
Number of hops whose resolved field is true.