pub struct IntegratorConfig {
pub embedding_dim: usize,
pub max_symbols: usize,
pub inference_depth: usize,
pub similarity_threshold: f64,
}Expand description
Configuration parameters for NeuralSymbolicIntegrator.
Fields
embedding_dim: usizeDimensionality that every symbol embedding must have.
max_symbols: usizeHard cap on the number of symbols that can be registered.
inference_depth: usizeMaximum recursion depth during symbolic forward-chaining.
similarity_threshold: f64Cosine-similarity threshold below which a symbol is not considered a
similar symbol in NeuralSymbolicIntegrator::similar_symbols.