pub struct NsQuery {
pub target: SymbolId,
pub evidence: Vec<(SymbolId, f64)>,
pub mode: InferenceMode,
}Expand description
A query to the integrator asking for the confidence of a target symbol given some observed evidence.
Fields
target: SymbolIdThe symbol whose confidence we want to estimate.
evidence: Vec<(SymbolId, f64)>Observed symbols and their associated confidence values.
mode: InferenceModeWhich inference strategy to apply.