pub struct ProofTreeInput {
pub root_goal: String,
pub nodes: HashMap<String, ProofNodeInput>,
pub proved: bool,
}Expand description
Full proof tree as produced by the distributed backward chainer.
Fields
root_goal: StringNode ID of the root goal.
nodes: HashMap<String, ProofNodeInput>All nodes in the tree, keyed by their node ID.
proved: boolWhether the root goal was successfully proved.