pub struct ProofTreeUpdateSink { /* private fields */ }Expand description
Receives streamed proof tree updates via an unbounded channel.
Implementations
Sourceimpl ProofTreeUpdateSink
impl ProofTreeUpdateSink
Sourcepub fn new() -> (Self, UnboundedReceiver<ProofTreeUpdate>)
pub fn new() -> (Self, UnboundedReceiver<ProofTreeUpdate>)
Create a new sink together with the receiving end of the channel.
Sourcepub fn send(&self, update: ProofTreeUpdate)
pub fn send(&self, update: ProofTreeUpdate)
Send an update. Silently drops the update if the channel is closed.