pub struct RuleSpec {
pub rule_id: String,
pub head_pattern: String,
pub arity: usize,
}Expand description
Specification of an inference rule used to validate proof nodes.
Fields
rule_id: StringUnique identifier for this rule.
head_pattern: StringPrefix pattern that the goal must start with for this rule to apply.
arity: usizeExpected number of premises (children) for this rule.