pub struct InferenceResponse {
pub request_id: String,
pub bindings: Vec<HashMap<String, String>>,
pub proof_found: bool,
pub error: Option<String>,
}Expand description
Wire format sent back by a remote peer in response to an InferenceRequest.
Fields
request_id: StringMatches the InferenceRequest::request_id.
bindings: Vec<HashMap<String, String>>Each element is one complete set of variable bindings that satisfy the goal.
proof_found: booltrue when at least one proof was found.
error: Option<String>Non-None when the remote engine encountered an error.