pub struct RuleSetDiff {
pub added: Vec<String>,
pub removed: Vec<String>,
pub unchanged: usize,
}Expand description
Diff between two rule sets.
Fields
added: Vec<String>Rules present in the new set but absent in the old set.
removed: Vec<String>Rules present in the old set but absent in the new set.
unchanged: usizeNumber of rules that appear in both sets.
Implementations