pub struct SnapshotDelta {
pub base_snapshot_id: u64,
pub new_snapshot_id: u64,
pub added_fields: Vec<SnapshotField>,
pub removed_fields: Vec<SnapshotField>,
pub size_delta_bytes: i64,
}Expand description
Difference between two StateSnapshots.
Fields
base_snapshot_id: u64Snapshot used as the baseline.
new_snapshot_id: u64Snapshot that was compared against the baseline.
added_fields: Vec<SnapshotField>Fields present in the newer snapshot but absent from the baseline.
removed_fields: Vec<SnapshotField>Fields present in the baseline but absent from the newer snapshot.
size_delta_bytes: i64Signed byte-size difference (new.total_size() - old.total_size()).
Implementations