pub enum OptimizationObjective {
Minimize,
Maximize,
Satisfy(Vec<String>),
}Expand description
The high-level goal of the optimization run.
Variants
Minimize
Minimize the scalar loss returned by the loss function.
Maximize
Maximize the scalar loss returned by the loss function (internally the optimizer negates the value so that a minimiser can be reused).
Satisfy(Vec<String>)
Satisfy the named constraints; loss is the total weighted violation.