pub struct ParameterVector {
pub values: Vec<f64>,
pub names: Vec<String>,
}Expand description
A named parameter vector.
Fields
values: Vec<f64>Parameter values.
names: Vec<String>Parameter names (parallel to values).
Implementations
Sourceimpl ParameterVector
impl ParameterVector
Sourcepub fn new(names: Vec<String>, values: Vec<f64>) -> Self
pub fn new(names: Vec<String>, values: Vec<f64>) -> Self
Construct a new ParameterVector.
If names and values lengths differ the shorter one determines the
logical length; the remainder is ignored.
Sourcepub fn get(&self, name: &str) -> Option<f64>
pub fn get(&self, name: &str) -> Option<f64>
Return the value of the parameter with the given name, if present.