pub enum AllenRelation {
Show 13 variants
Precedes,
Meets,
Overlaps,
FinishedBy,
Contains,
Starts,
Equals,
StartedBy,
During,
Finishes,
OverlappedBy,
MetBy,
PrecededBy,
}Expand description
The 13 relations of Allen’s interval algebra.
Variants
Precedes
a ends strictly before b starts.
Meets
a ends exactly when b starts.
Overlaps
a starts before b and ends inside b.
FinishedBy
a starts before b and ends exactly when b ends.
Contains
a starts before b starts and ends after b ends.
Starts
a and b start at the same point; a ends before b.
Equals
a and b are identical.
StartedBy
a and b start at the same point; b ends before a.
During
a starts after b starts and ends before b ends (proper subset).
Finishes
a starts after b starts and ends exactly when b ends.
OverlappedBy
b starts before a and ends inside a.
MetBy
a starts exactly when b ends.
PrecededBy
a starts strictly after b ends.
Implementations
Sourceimpl AllenRelation
impl AllenRelation
Sourcepub fn classify(a: &TimeInterval, b: &TimeInterval) -> AllenRelation
pub fn classify(a: &TimeInterval, b: &TimeInterval) -> AllenRelation
Classify two intervals into exactly one Allen relation.
Sourcepub fn is_overlapping_kind(self) -> bool
pub fn is_overlapping_kind(self) -> bool
Returns true when the two intervals share any common point under this
relation (i.e. the relation is not a strict precede or strict follow).