pub enum TemporalConstraint {
Before {
a: String,
b: String,
},
After {
a: String,
b: String,
},
Overlapping {
a: String,
b: String,
},
During {
inner: String,
outer: String,
},
Within {
event: String,
window: TimeInterval,
},
}Expand description
Constraints that can be enforced across events.
Variants
Before
Event a must end before event b starts.
After
Event a must start after event b ends.
Overlapping
Events a and b must share at least one point in time.
During
Event inner must be entirely contained within event outer.
Within
Event event must overlap with the given fixed window.