pub enum GcPhase {
MarkRoots,
Trace,
Sweep,
}Expand description
The current phase of a mark-and-sweep garbage collection cycle.
Variants
MarkRoots
Phase 1 — seed the reachable set from roots and pinned tensors.
Trace
Phase 2 — BFS/DFS expansion of the reachable set through dependency edges.
Sweep
Phase 3 — remove tensors absent from the reachable set that have no external references.