pub struct TensorPoolConfig {
pub max_per_bucket: usize,
}Expand description
Configuration for TensorPool.
Fields
max_per_bucket: usizeMaximum number of free buffers to retain per bucket.
When a buffer is released back to the pool and the corresponding free list
already has max_per_bucket entries, the buffer is simply dropped.