pub struct CacheKey {
pub goal_hash: u64,
pub kb_id: String,
pub kb_version: u64,
}Expand description
Composite key for a single cached inference result.
Two keys are equal iff goal_hash, kb_id, and kb_version all match.
This means the same goal cached against version 1 and version 2 of the same
KB are stored as completely independent entries.
Fields
goal_hash: u64FNV-1a hash of the goal string.
kb_id: StringIdentifier of the knowledge base that was queried.
kb_version: u64Version of the knowledge base at the time of inference.
Implementations