pub struct TensorChecksum {
pub algorithm: ChecksumAlgorithm,
pub value: u64,
pub data_len: usize,
pub computed_at_secs: u64,
}Expand description
A checksum value together with the metadata needed to re-verify data later.
Fields
algorithm: ChecksumAlgorithmAlgorithm used to produce value.
value: u64The checksum value.
data_len: usizeLength (in bytes) of the data that was checksummed.
computed_at_secs: u64Unix timestamp (seconds) at which the checksum was computed.
Implementations
Sourceimpl TensorChecksum
impl TensorChecksum
Sourcepub fn verify(&self, data: &[u8]) -> bool
pub fn verify(&self, data: &[u8]) -> bool
Recompute the checksum for data using the same algorithm and compare
it against self.value.
Returns true if the data is intact, false if it has been corrupted
(or if data.len() != self.data_len).
Examples
use ipfrs_tensorlogic::tensor_checksum::{ChecksumAlgorithm, TensorChecksum};
let data = b"tensor payload";
let cs = TensorChecksum {
algorithm: ChecksumAlgorithm::Fnv1a64,
value: ipfrs_tensorlogic::tensor_checksum::fnv1a64(data),
data_len: data.len(),
computed_at_secs: 0,
};
assert!(cs.verify(data));
assert!(!cs.verify(b"corrupted payload"));Trait Implementations
Sourceimpl Clone for TensorChecksum
impl Clone for TensorChecksum
Sourcefn clone(&self) -> TensorChecksum
fn clone(&self) -> TensorChecksum
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TensorChecksum
impl Debug for TensorChecksum
impl Eq for TensorChecksum
Sourceimpl PartialEq for TensorChecksum
impl PartialEq for TensorChecksum
Sourcefn eq(&self, other: &TensorChecksum) -> bool
fn eq(&self, other: &TensorChecksum) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TensorChecksum